#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ram
version:              0.22.1
visibility:           public
id:                   ram-0.22.1-IpmBIvEBkfy9DyGaa6XfPr
key:                  ram-0.22.1-IpmBIvEBkfy9DyGaa6XfPr
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           hi@jappie.me
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/jappeace/ram
synopsis:             memory and related abstraction stuff
description:
    This is a fork of memory. It'\''s open to accept changes from anyone,
    and aims to use existing well maintained libraries as much as possible.

    Chunk of memory, polymorphic byte array management and manipulation

    * A polymorphic byte array abstraction and function similar to strict ByteString.

    * Different type of byte array abstraction.

    * Raw memory IO operations (memory set, memory copy, ..)

    * Aliasing with endianness support.

    * Encoding : Base16, Base32, Base64.

    * Hashing : FNV, SipHash

category:             memory
abi:                  d90934a191c481680c2d3e405c16c856
exposed:              True
exposed-modules:
    Data.ByteArray Data.ByteArray.Encoding Data.ByteArray.Hash
    Data.ByteArray.Mapping Data.ByteArray.Pack Data.ByteArray.Parse
    Data.ByteArray.Sized Data.Memory.Encoding.Base16
    Data.Memory.Encoding.Base32 Data.Memory.Encoding.Base64
    Data.Memory.Endian Data.Memory.ExtendedWords Data.Memory.PtrMethods

hidden-modules:
    Data.ByteArray.Bytes Data.ByteArray.MemView Data.ByteArray.Methods
    Data.ByteArray.Pack.Internal Data.ByteArray.ScrubbedBytes
    Data.ByteArray.Types Data.ByteArray.View Data.Memory.Hash.FNV
    Data.Memory.Hash.SipHash Data.Memory.Internal.Compat
    Data.Memory.Internal.CompatPrim Data.Memory.Internal.Imports
    Data.Memory.MemMap.Posix

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ram-0.22.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ram-0.22.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ram-0.22.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ram
hs-libraries:         HSram-0.22.1-IpmBIvEBkfy9DyGaa6XfPr
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 ghc-prim-0.10.0

haddock-interfaces:   /usr/share/doc/haskell-ram/html/ram.haddock
haddock-html:         /usr/share/doc/haskell-ram/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

